@@ -32,7 +32,7 @@ import logging
 from mechanize import (
     LinkNotFoundError, FormNotFoundError, ControlNotFoundError
 )
-from BeautifulSoup import BeautifulSoup
+from bs4 import BeautifulSoup
 
 from suseapi.browser import WebScraper, WebScraperError
 
@@ -248,24 +248,18 @@ class Bugzilla(WebScraper):
         if self.check_login():
             return
 
-        # Submit fake javascript form
         try:
+            # Submit fake javascript form
             self.browser.select_form(nr=0)
-        except FormNotFoundError:
-            raise BugzillaUpdateError('Failed to parse HTML for login!')
-        response = self._submit()
+            response = self._submit()
 
-        # Find the login form
-        try:
+            # Find the login form
             self.browser.select_form(nr=0)
-        except FormNotFoundError:
-            raise BugzillaUpdateError('Failed to parse HTML for login!')
 
-        try:
             self.browser['Ecom_User_ID'] = self.user
             self.browser['Ecom_Password'] = self.password
-        except ControlNotFoundError:
-            raise BugzillaUpdateError('Failed to parse HTML for login!')
+        except (FormNotFoundError, ControlNotFoundError):
+            raise BugzillaLoginFailed('Failed to parse HTML for login!')
 
         self.logger.info('Doing login')
         response = self._submit()
@@ -274,8 +268,8 @@ class Bugzilla(WebScraper):
 
         # Check for error messages
         soup = BeautifulSoup(text)
-        for para in soup.findAll('p'):
-            if para.get('class') == 'error':
+        for para in soup.find_all('p'):
+            if 'error' in para['class']:
                 raise BugzillaLoginFailed(para.text)
 
         # Emulate javascript redirect
@@ -551,8 +545,10 @@ class Bugzilla(WebScraper):
         self.browser['status_whiteboard'] = whiteboard
 
         # Do not add ourselves to cc
-        if 'addselfcc' in self.browser:
+        try:
             self.browser['addselfcc'] = []
+        except ControlNotFoundError:
+            pass
 
         return changes
 
